==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/inputs/AzureActiveDirectoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.inputs

import com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The settings to enable AAD authentication on the cluster.
 * @property clientApplication Azure active directory client application id.
 * @property clusterApplication Azure active directory cluster application id.
 * @property tenantId Azure active directory tenant id.
 */
public data class AzureActiveDirectoryArgs(
    public val clientApplication: Output<String>? = null,
    public val clusterApplication: Output<String>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs =
        com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs.builder()
            .clientApplication(clientApplication?.applyValue({ args0 -> args0 }))
            .clusterApplication(clusterApplication?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureActiveDirectoryArgs].
 */
@PulumiTagMarker
public class AzureActiveDirectoryArgsBuilder internal constructor() {
    private var clientApplication: Output<String>? = null

    private var clusterApplication: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Azure active directory client application id.
     */
    @JvmName("irfibcieiwcgafeo")
    public suspend fun clientApplication(`value`: Output<String>) {
        this.clientApplication = value
    }

    /**
     * @param value Azure active directory cluster application id.
     */
    @JvmName("qafxtnbctejbduxi")
    public suspend fun clusterApplication(`value`: Output<String>) {
        this.clusterApplication = value
    }

    /**
     * @param value Azure active directory tenant id.
     */
    @JvmName("crmabubasuhqkyso")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Azure active directory client application id.
     */
    @JvmName("awatqltjfygytsfe")
    public suspend fun clientApplication(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientApplication = mapped
    }

    /**
     * @param value Azure active directory cluster application id.
     */
    @JvmName("ewwmeekogmpiorpa")
    public suspend fun clusterApplication(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterApplication = mapped
    }

    /**
     * @param value Azure active directory tenant id.
     */
    @JvmName("bssfeumyqlydngwr")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): AzureActiveDirectoryArgs = AzureActiveDirectoryArgs(
        clientApplication = clientApplication,
        clusterApplication = clusterApplication,
        tenantId = tenantId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/inputs/AzureActiveDirectoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.inputs

import com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The settings to enable AAD authentication on the cluster.
 * @property clientApplication Azure active directory client application id.
 * @property clusterApplication Azure active directory cluster application id.
 * @property tenantId Azure active directory tenant id.
 */
public data class AzureActiveDirectoryArgs(
    public val clientApplication: Output<String>? = null,
    public val clusterApplication: Output<String>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs =
        com.pulumi.azurenative.servicefabric.inputs.AzureActiveDirectoryArgs.builder()
            .clientApplication(clientApplication?.applyValue({ args0 -> args0 }))
            .clusterApplication(clusterApplication?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureActiveDirectoryArgs].
 */
@PulumiTagMarker
public class AzureActiveDirectoryArgsBuilder internal constructor() {
    private var clientApplication: Output<String>? = null

    private var clusterApplication: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Azure active directory client application id.
     */
    @JvmName("aixbkaovinwgemdi")
    public suspend fun clientApplication(`value`: Output<String>) {
        this.clientApplication = value
    }

    /**
     * @param value Azure active directory cluster application id.
     */
    @JvmName("uulvqrjnwlxkjqcn")
    public suspend fun clusterApplication(`value`: Output<String>) {
        this.clusterApplication = value
    }

    /**
     * @param value Azure active directory tenant id.
     */
    @JvmName("scsxhacuibytcywr")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Azure active directory client application id.
     */
    @JvmName("cvpiexqardptklif")
    public suspend fun clientApplication(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientApplication = mapped
    }

    /**
     * @param value Azure active directory cluster application id.
     */
    @JvmName("jossdqjexmpivhyt")
    public suspend fun clusterApplication(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterApplication = mapped
    }

    /**
     * @param value Azure active directory tenant id.
     */
    @JvmName("hfelxihrvwpwfiob")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): AzureActiveDirectoryArgs = AzureActiveDirectoryArgs(
        clientApplication = clientApplication,
        clusterApplication = clusterApplication,
        tenantId = tenantId,
    )
}
